@@ -41,6 +41,8 @@
 
 #define KDECLARATIVE_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(KDECLARATIVE_NO_DEPRECATED) && !defined(KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define KDECLARATIVE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDECLARATIVE_NO_DEPRECATED
-#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56f00
+#  define KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54000
 #endif
 #ifdef KDECLARATIVE_NO_DEPRECATED_WARNINGS
 #  define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x56f00
+#    define KDECLARATIVE_DEPRECATED_WARNINGS_SINCE 0x54000
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef KDECLARATIVE_DEPRECATED
-#  define KDECLARATIVE_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define KDECLARATIVE_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > KDECLARATIVE_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define KDECLARATIVE_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -119,45 +121,7 @@
 #else
 #  define KDECLARATIVE_DEPRECATED_VERSION_5_45(text)
 #endif
-
-#if KDECLARATIVE_DEPRECATED_WARNINGS_SINCE >= 0x54b00
-#  define KDECLARATIVE_DEPRECATED_VERSION_5_75(text) KDECLARATIVE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KDECLARATIVE_DEPRECATED_VERSION_5_75(text)
-#endif
-
-#if KDECLARATIVE_DEPRECATED_WARNINGS_SINCE >= 0x55b00
-#  define KDECLARATIVE_DEPRECATED_VERSION_5_91(text) KDECLARATIVE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KDECLARATIVE_DEPRECATED_VERSION_5_91(text)
-#endif
-
-#if KDECLARATIVE_DEPRECATED_WARNINGS_SINCE >= 0x55f00
-#  define KDECLARATIVE_DEPRECATED_VERSION_5_95(text) KDECLARATIVE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KDECLARATIVE_DEPRECATED_VERSION_5_95(text)
-#endif
-
-#if KDECLARATIVE_DEPRECATED_WARNINGS_SINCE >= 0x56200
-#  define KDECLARATIVE_DEPRECATED_VERSION_5_98(text) KDECLARATIVE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KDECLARATIVE_DEPRECATED_VERSION_5_98(text)
-#endif
-
-#if KDECLARATIVE_DEPRECATED_WARNINGS_SINCE >= 0x56400
-#  define KDECLARATIVE_DEPRECATED_VERSION_5_100(text) KDECLARATIVE_DECL_DEPRECATED_TEXT(text)
-#else
-#  define KDECLARATIVE_DEPRECATED_VERSION_5_100(text)
-#endif
 #define KDECLARATIVE_DEPRECATED_VERSION_5(minor, text)      KDECLARATIVE_DEPRECATED_VERSION_5_##minor(text)
 #define KDECLARATIVE_DEPRECATED_VERSION(major, minor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define KDECLARATIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDECLARATIVE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define KDECLARATIVE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KDECLARATIVE_DEPRECATED_VERSION(major, minor, text)
-#  define KDECLARATIVE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDECLARATIVE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define KDECLARATIVE_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define KDECLARATIVE_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* KDECLARATIVE_EXPORT_H */
